Orange3 Educational Add-on
==========================

Widgets in Educational Add-on demonstrate several key data mining and machine learning procedures.
The widgets are useful for beginners to understand the inner working of key algorithms in the data
mining and for teachers to be able to visually explain various methods in a classroom.

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/google-sheets
   widgets/enklik-anketa
   widgets/interactive-kmeans
   widgets/gradient-descent
   widgets/polynomial-regression
   widgets/polynomial-classification
   widgets/pie-chart
   widgets/random-data

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

